import { type ValidateCredentialsPostRequestBody } from './validateCredentialsPostRequestBody';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
/**
 * Provides operations to call the validateCredentials method.
 */
export declare class ValidateCredentialsRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new ValidateCredentialsRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Validate that the credentials are valid in the tenant.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/synchronization-synchronizationjob-validatecredentials?view=graph-rest-1.0|Find more info here}
     */
    post(body: ValidateCredentialsPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Validate that the credentials are valid in the tenant.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: ValidateCredentialsPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a validateCredentialsRequestBuilder
     */
    withUrl(rawUrl: string): ValidateCredentialsRequestBuilder;
}
