"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PromoteRequestBuilder = void 0;
const oDataError_1 = require("../../../models/oDataErrors/oDataError");
const promotePostResponse_1 = require("./promotePostResponse");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to call the promote method.
 */
class PromoteRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Instantiates a new PromoteRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/domains/{domain%2Did}/promote");
    }
    ;
    /**
     * Promote a verified subdomain to the root domain. A verified domain has its isVerified property set to true.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of PromotePostResponse
     * @see {@link https://learn.microsoft.com/graph/api/domain-promote?view=graph-rest-1.0|Find more info here}
     */
    post(requestConfiguration) {
        const requestInfo = this.toPostRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, promotePostResponse_1.createPromotePostResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Promote a verified subdomain to the root domain. A verified domain has its isVerified property set to true.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.POST, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a promoteRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new PromoteRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.PromoteRequestBuilder = PromoteRequestBuilder;
// tslint:enable
// eslint-enable
