import { type DriveItem } from '../../../../models/driveItem';
import { AnalyticsRequestBuilder } from './analytics/analyticsRequestBuilder';
import { AssignSensitivityLabelRequestBuilder } from './assignSensitivityLabel/assignSensitivityLabelRequestBuilder';
import { CheckinRequestBuilder } from './checkin/checkinRequestBuilder';
import { CheckoutRequestBuilder } from './checkout/checkoutRequestBuilder';
import { ChildrenRequestBuilder } from './children/childrenRequestBuilder';
import { ContentRequestBuilder } from './content/contentRequestBuilder';
import { CopyRequestBuilder } from './copy/copyRequestBuilder';
import { CreatedByUserRequestBuilder } from './createdByUser/createdByUserRequestBuilder';
import { CreateLinkRequestBuilder } from './createLink/createLinkRequestBuilder';
import { CreateUploadSessionRequestBuilder } from './createUploadSession/createUploadSessionRequestBuilder';
import { DeltaRequestBuilder } from './delta/deltaRequestBuilder';
import { DeltaWithTokenRequestBuilder } from './deltaWithToken/deltaWithTokenRequestBuilder';
import { ExtractSensitivityLabelsRequestBuilder } from './extractSensitivityLabels/extractSensitivityLabelsRequestBuilder';
import { FollowRequestBuilder } from './follow/followRequestBuilder';
import { GetActivitiesByIntervalRequestBuilder } from './getActivitiesByInterval/getActivitiesByIntervalRequestBuilder';
import { GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder } from './getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval/getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder';
import { InviteRequestBuilder } from './invite/inviteRequestBuilder';
import { LastModifiedByUserRequestBuilder } from './lastModifiedByUser/lastModifiedByUserRequestBuilder';
import { ListItemRequestBuilder } from './listItem/listItemRequestBuilder';
import { PermanentDeleteRequestBuilder } from './permanentDelete/permanentDeleteRequestBuilder';
import { PermissionsRequestBuilder } from './permissions/permissionsRequestBuilder';
import { PreviewRequestBuilder } from './preview/previewRequestBuilder';
import { RestoreRequestBuilder } from './restore/restoreRequestBuilder';
import { RetentionLabelRequestBuilder } from './retentionLabel/retentionLabelRequestBuilder';
import { SearchWithQRequestBuilder } from './searchWithQ/searchWithQRequestBuilder';
import { SubscriptionsRequestBuilder } from './subscriptions/subscriptionsRequestBuilder';
import { ThumbnailsRequestBuilder } from './thumbnails/thumbnailsRequestBuilder';
import { UnfollowRequestBuilder } from './unfollow/unfollowRequestBuilder';
import { ValidatePermissionRequestBuilder } from './validatePermission/validatePermissionRequestBuilder';
import { VersionsRequestBuilder } from './versions/versionsRequestBuilder';
import { WorkbookRequestBuilder } from './workbook/workbookRequestBuilder';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
export interface DriveItemItemRequestBuilderGetQueryParameters {
    /**
     * Expand related entities
     */
    expand?: string[];
    /**
     * Select properties to be returned
     */
    select?: string[];
}
/**
 * Provides operations to manage the items property of the microsoft.graph.drive entity.
 */
export declare class DriveItemItemRequestBuilder extends BaseRequestBuilder {
    /**
     * Provides operations to manage the analytics property of the microsoft.graph.driveItem entity.
     */
    get analytics(): AnalyticsRequestBuilder;
    /**
     * Provides operations to call the assignSensitivityLabel method.
     */
    get assignSensitivityLabel(): AssignSensitivityLabelRequestBuilder;
    /**
     * Provides operations to call the checkin method.
     */
    get checkin(): CheckinRequestBuilder;
    /**
     * Provides operations to call the checkout method.
     */
    get checkout(): CheckoutRequestBuilder;
    /**
     * Provides operations to manage the children property of the microsoft.graph.driveItem entity.
     */
    get children(): ChildrenRequestBuilder;
    /**
     * Provides operations to manage the media for the drive entity.
     */
    get content(): ContentRequestBuilder;
    /**
     * Provides operations to call the copy method.
     */
    get copy(): CopyRequestBuilder;
    /**
     * Provides operations to manage the createdByUser property of the microsoft.graph.baseItem entity.
     */
    get createdByUser(): CreatedByUserRequestBuilder;
    /**
     * Provides operations to call the createLink method.
     */
    get createLink(): CreateLinkRequestBuilder;
    /**
     * Provides operations to call the createUploadSession method.
     */
    get createUploadSession(): CreateUploadSessionRequestBuilder;
    /**
     * Provides operations to call the delta method.
     */
    get delta(): DeltaRequestBuilder;
    /**
     * Provides operations to call the extractSensitivityLabels method.
     */
    get extractSensitivityLabels(): ExtractSensitivityLabelsRequestBuilder;
    /**
     * Provides operations to call the follow method.
     */
    get follow(): FollowRequestBuilder;
    /**
     * Provides operations to call the getActivitiesByInterval method.
     */
    get getActivitiesByInterval(): GetActivitiesByIntervalRequestBuilder;
    /**
     * Provides operations to call the invite method.
     */
    get invite(): InviteRequestBuilder;
    /**
     * Provides operations to manage the lastModifiedByUser property of the microsoft.graph.baseItem entity.
     */
    get lastModifiedByUser(): LastModifiedByUserRequestBuilder;
    /**
     * Provides operations to manage the listItem property of the microsoft.graph.driveItem entity.
     */
    get listItem(): ListItemRequestBuilder;
    /**
     * Provides operations to call the permanentDelete method.
     */
    get permanentDelete(): PermanentDeleteRequestBuilder;
    /**
     * Provides operations to manage the permissions property of the microsoft.graph.driveItem entity.
     */
    get permissions(): PermissionsRequestBuilder;
    /**
     * Provides operations to call the preview method.
     */
    get preview(): PreviewRequestBuilder;
    /**
     * Provides operations to call the restore method.
     */
    get restore(): RestoreRequestBuilder;
    /**
     * Provides operations to manage the retentionLabel property of the microsoft.graph.driveItem entity.
     */
    get retentionLabel(): RetentionLabelRequestBuilder;
    /**
     * Provides operations to manage the subscriptions property of the microsoft.graph.driveItem entity.
     */
    get subscriptions(): SubscriptionsRequestBuilder;
    /**
     * Provides operations to manage the thumbnails property of the microsoft.graph.driveItem entity.
     */
    get thumbnails(): ThumbnailsRequestBuilder;
    /**
     * Provides operations to call the unfollow method.
     */
    get unfollow(): UnfollowRequestBuilder;
    /**
     * Provides operations to call the validatePermission method.
     */
    get validatePermission(): ValidatePermissionRequestBuilder;
    /**
     * Provides operations to manage the versions property of the microsoft.graph.driveItem entity.
     */
    get versions(): VersionsRequestBuilder;
    /**
     * Provides operations to manage the workbook property of the microsoft.graph.driveItem entity.
     */
    get workbook(): WorkbookRequestBuilder;
    /**
     * Instantiates a new DriveItemItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Delete a DriveItem by using its ID or path.Deleting items using this method moves the items to the recycle bin instead of permanently deleting the item.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/driveitem-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration?: RequestConfiguration<object> | undefined): Promise<void>;
    /**
     * Provides operations to call the delta method.
     * @param token Usage: token='{token}'
     * @returns a deltaWithTokenRequestBuilder
     */
    deltaWithToken(token: string | undefined): DeltaWithTokenRequestBuilder;
    /**
     * All items contained in the drive. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DriveItem
     */
    get(requestConfiguration?: RequestConfiguration<DriveItemItemRequestBuilderGetQueryParameters> | undefined): Promise<DriveItem | undefined>;
    /**
     * Provides operations to call the getActivitiesByInterval method.
     * @param endDateTime Usage: endDateTime='{endDateTime}'
     * @param interval Usage: interval='{interval}'
     * @param startDateTime Usage: startDateTime='{startDateTime}'
     * @returns a getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder
     */
    getActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithInterval(endDateTime: string | undefined, interval: string | undefined, startDateTime: string | undefined): GetActivitiesByIntervalWithStartDateTimeWithEndDateTimeWithIntervalRequestBuilder;
    /**
     * Update the metadata for a driveItem by ID or path. You can also use update to move an item to another parent by updating the item's parentReference property.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DriveItem
     * @see {@link https://learn.microsoft.com/graph/api/driveitem-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body: DriveItem, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<DriveItem | undefined>;
    /**
     * Provides operations to call the search method.
     * @param q Usage: q='{q}'
     * @returns a searchWithQRequestBuilder
     */
    searchWithQ(q: string | undefined): SearchWithQRequestBuilder;
    /**
     * Delete a DriveItem by using its ID or path.Deleting items using this method moves the items to the recycle bin instead of permanently deleting the item.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * All items contained in the drive. Read-only. Nullable.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration?: RequestConfiguration<DriveItemItemRequestBuilderGetQueryParameters> | undefined): RequestInformation;
    /**
     * Update the metadata for a driveItem by ID or path. You can also use update to move an item to another parent by updating the item's parentReference property.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body: DriveItem, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a DriveItemItemRequestBuilder
     */
    withUrl(rawUrl: string): DriveItemItemRequestBuilder;
}
