"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.WorkbookChartItemRequestBuilder = void 0;
const oDataError_1 = require("../../../../../../../../../models/oDataErrors/oDataError");
const workbookChart_1 = require("../../../../../../../../../models/workbookChart");
const axesRequestBuilder_1 = require("./axes/axesRequestBuilder");
const dataLabelsRequestBuilder_1 = require("./dataLabels/dataLabelsRequestBuilder");
const formatRequestBuilder_1 = require("./format/formatRequestBuilder");
const imageRequestBuilder_1 = require("./image/imageRequestBuilder");
const imageWithWidthRequestBuilder_1 = require("./imageWithWidth/imageWithWidthRequestBuilder");
const imageWithWidthWithHeightRequestBuilder_1 = require("./imageWithWidthWithHeight/imageWithWidthWithHeightRequestBuilder");
const imageWithWidthWithHeightWithFittingModeRequestBuilder_1 = require("./imageWithWidthWithHeightWithFittingMode/imageWithWidthWithHeightWithFittingModeRequestBuilder");
const legendRequestBuilder_1 = require("./legend/legendRequestBuilder");
const seriesRequestBuilder_1 = require("./series/seriesRequestBuilder");
const setDataRequestBuilder_1 = require("./setData/setDataRequestBuilder");
const setPositionRequestBuilder_1 = require("./setPosition/setPositionRequestBuilder");
const titleRequestBuilder_1 = require("./title/titleRequestBuilder");
const worksheetRequestBuilder_1 = require("./worksheet/worksheetRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the charts property of the microsoft.graph.workbookWorksheet entity.
 */
class WorkbookChartItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to manage the axes property of the microsoft.graph.workbookChart entity.
     */
    get axes() {
        return new axesRequestBuilder_1.AxesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the dataLabels property of the microsoft.graph.workbookChart entity.
     */
    get dataLabels() {
        return new dataLabelsRequestBuilder_1.DataLabelsRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the format property of the microsoft.graph.workbookChart entity.
     */
    get format() {
        return new formatRequestBuilder_1.FormatRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the image method.
     */
    get image() {
        return new imageRequestBuilder_1.ImageRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the legend property of the microsoft.graph.workbookChart entity.
     */
    get legend() {
        return new legendRequestBuilder_1.LegendRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the series property of the microsoft.graph.workbookChart entity.
     */
    get series() {
        return new seriesRequestBuilder_1.SeriesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the setData method.
     */
    get setData() {
        return new setDataRequestBuilder_1.SetDataRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the setPosition method.
     */
    get setPosition() {
        return new setPositionRequestBuilder_1.SetPositionRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the title property of the microsoft.graph.workbookChart entity.
     */
    get title() {
        return new titleRequestBuilder_1.TitleRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the worksheet property of the microsoft.graph.workbookChart entity.
     */
    get worksheet() {
        return new worksheetRequestBuilder_1.WorksheetRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new WorkbookChartItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/drives/{drive%2Did}/items/{driveItem%2Did}/workbook/worksheets/{workbookWorksheet%2Did}/charts/{workbookChart%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * Deletes the chart object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @see {@link https://learn.microsoft.com/graph/api/chart-delete?view=graph-rest-1.0|Find more info here}
     */
    delete(requestConfiguration) {
        const requestInfo = this.toDeleteRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendNoResponseContentAsync(requestInfo, errorMapping);
    }
    ;
    /**
     * Retrieve the properties and relationships of chart object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChart
     * @see {@link https://learn.microsoft.com/graph/api/chart-get?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbookChart_1.createWorkbookChartFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Provides operations to call the image method.
     * @param width Usage: width={width}
     * @returns a imageWithWidthRequestBuilder
     */
    imageWithWidth(width) {
        if (!width)
            throw new Error("width cannot be undefined");
        return new imageWithWidthRequestBuilder_1.ImageWithWidthRequestBuilder(this.pathParameters, this.requestAdapter, width);
    }
    ;
    /**
     * Provides operations to call the image method.
     * @param height Usage: height={height}
     * @param width Usage: width={width}
     * @returns a imageWithWidthWithHeightRequestBuilder
     */
    imageWithWidthWithHeight(height, width) {
        if (!height)
            throw new Error("height cannot be undefined");
        if (!width)
            throw new Error("width cannot be undefined");
        return new imageWithWidthWithHeightRequestBuilder_1.ImageWithWidthWithHeightRequestBuilder(this.pathParameters, this.requestAdapter, height, width);
    }
    ;
    /**
     * Provides operations to call the image method.
     * @param fittingMode Usage: fittingMode='{fittingMode}'
     * @param height Usage: height={height}
     * @param width Usage: width={width}
     * @returns a imageWithWidthWithHeightWithFittingModeRequestBuilder
     */
    imageWithWidthWithHeightWithFittingMode(fittingMode, height, width) {
        if (!fittingMode)
            throw new Error("fittingMode cannot be undefined");
        if (!height)
            throw new Error("height cannot be undefined");
        if (!width)
            throw new Error("width cannot be undefined");
        return new imageWithWidthWithHeightWithFittingModeRequestBuilder_1.ImageWithWidthWithHeightWithFittingModeRequestBuilder(this.pathParameters, this.requestAdapter, fittingMode, height, width);
    }
    ;
    /**
     * Update the properties of chart object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of WorkbookChart
     * @see {@link https://learn.microsoft.com/graph/api/chart-update?view=graph-rest-1.0|Find more info here}
     */
    patch(body, requestConfiguration) {
        const requestInfo = this.toPatchRequestInformation(body, requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, workbookChart_1.createWorkbookChartFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * Deletes the chart object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toDeleteRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.DELETE, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Retrieve the properties and relationships of chart object.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, workbookChartItemRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Update the properties of chart object.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPatchRequestInformation(body, requestConfiguration) {
        if (!body)
            throw new Error("body cannot be undefined");
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.PATCH, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration);
        requestInfo.headers.tryAdd("Accept", "application/json");
        requestInfo.setContentFromParsable(this.requestAdapter, "application/json", body, workbookChart_1.serializeWorkbookChart);
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a WorkbookChartItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new WorkbookChartItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.WorkbookChartItemRequestBuilder = WorkbookChartItemRequestBuilder;
const workbookChartItemRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
