"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DirectoryObjectItemRequestBuilder = void 0;
const directoryObject_1 = require("../../../../models/directoryObject");
const oDataError_1 = require("../../../../models/oDataErrors/oDataError");
const graphApplicationRequestBuilder_1 = require("./graphApplication/graphApplicationRequestBuilder");
const graphDeviceRequestBuilder_1 = require("./graphDevice/graphDeviceRequestBuilder");
const graphGroupRequestBuilder_1 = require("./graphGroup/graphGroupRequestBuilder");
const graphOrgContactRequestBuilder_1 = require("./graphOrgContact/graphOrgContactRequestBuilder");
const graphServicePrincipalRequestBuilder_1 = require("./graphServicePrincipal/graphServicePrincipalRequestBuilder");
const graphUserRequestBuilder_1 = require("./graphUser/graphUserRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the membersWithLicenseErrors property of the microsoft.graph.group entity.
 */
class DirectoryObjectItemRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Casts the previous resource to application.
     */
    get graphApplication() {
        return new graphApplicationRequestBuilder_1.GraphApplicationRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Casts the previous resource to device.
     */
    get graphDevice() {
        return new graphDeviceRequestBuilder_1.GraphDeviceRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Casts the previous resource to group.
     */
    get graphGroup() {
        return new graphGroupRequestBuilder_1.GraphGroupRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Casts the previous resource to orgContact.
     */
    get graphOrgContact() {
        return new graphOrgContactRequestBuilder_1.GraphOrgContactRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Casts the previous resource to servicePrincipal.
     */
    get graphServicePrincipal() {
        return new graphServicePrincipalRequestBuilder_1.GraphServicePrincipalRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Casts the previous resource to user.
     */
    get graphUser() {
        return new graphUserRequestBuilder_1.GraphUserRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Instantiates a new DirectoryObjectItemRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/groups/{group%2Did}/membersWithLicenseErrors/{directoryObject%2Did}{?%24select,%24expand}");
    }
    ;
    /**
     * A list of group members with license errors from this group-based license assignment. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of DirectoryObject
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, directoryObject_1.createDirectoryObjectFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * A list of group members with license errors from this group-based license assignment. Read-only.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, directoryObjectItemRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a DirectoryObjectItemRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new DirectoryObjectItemRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.DirectoryObjectItemRequestBuilder = DirectoryObjectItemRequestBuilder;
const directoryObjectItemRequestBuilderGetQueryParametersMapper = {
    "expand": "%24expand",
    "select": "%24select",
};
// tslint:enable
// eslint-enable
