import { type QueryPostRequestBody } from './queryPostRequestBody';
import { type QueryPostResponse } from './queryPostResponse';
import { BaseRequestBuilder, RequestInformation, type RequestAdapter, type RequestConfiguration } from '@microsoft/kiota-abstractions';
/**
 * Provides operations to call the query method.
 */
export declare class QueryRequestBuilder extends BaseRequestBuilder {
    /**
     * Instantiates a new QueryRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters: Record<string, unknown> | string | undefined, requestAdapter: RequestAdapter);
    /**
     * Runs the query specified in the request body. Search results are provided in the response.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of QueryPostResponse
     * @see {@link https://learn.microsoft.com/graph/api/search-query?view=graph-rest-1.0|Find more info here}
     */
    post(body: QueryPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): Promise<QueryPostResponse | undefined>;
    /**
     * Runs the query specified in the request body. Search results are provided in the response.
     * @param body The request body
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toPostRequestInformation(body: QueryPostRequestBody, requestConfiguration?: RequestConfiguration<object> | undefined): RequestInformation;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a queryRequestBuilder
     */
    withUrl(rawUrl: string): QueryRequestBuilder;
}
