"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SitesRequestBuilder = void 0;
const oDataError_1 = require("../models/oDataErrors/oDataError");
const siteCollectionResponse_1 = require("../models/siteCollectionResponse");
const addRequestBuilder_1 = require("./add/addRequestBuilder");
const countRequestBuilder_1 = require("./count/countRequestBuilder");
const deltaRequestBuilder_1 = require("./delta/deltaRequestBuilder");
const getAllSitesRequestBuilder_1 = require("./getAllSites/getAllSitesRequestBuilder");
const siteItemRequestBuilder_1 = require("./item/siteItemRequestBuilder");
const removeRequestBuilder_1 = require("./remove/removeRequestBuilder");
const kiota_abstractions_1 = require("@microsoft/kiota-abstractions");
/**
 * Provides operations to manage the collection of site entities.
 */
class SitesRequestBuilder extends kiota_abstractions_1.BaseRequestBuilder {
    /**
     * Provides operations to call the add method.
     */
    get add() {
        return new addRequestBuilder_1.AddRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to count the resources in the collection.
     */
    get count() {
        return new countRequestBuilder_1.CountRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the delta method.
     */
    get delta() {
        return new deltaRequestBuilder_1.DeltaRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the getAllSites method.
     */
    get getAllSites() {
        return new getAllSitesRequestBuilder_1.GetAllSitesRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to call the remove method.
     */
    get remove() {
        return new removeRequestBuilder_1.RemoveRequestBuilder(this.pathParameters, this.requestAdapter);
    }
    /**
     * Provides operations to manage the collection of site entities.
     * @param siteId The unique identifier of site
     * @returns a SiteItemRequestBuilder
     */
    bySiteId(siteId) {
        if (!siteId)
            throw new Error("siteId cannot be undefined");
        const urlTplParams = (0, kiota_abstractions_1.getPathParameters)(this.pathParameters);
        urlTplParams["site%2Did"] = siteId;
        return new siteItemRequestBuilder_1.SiteItemRequestBuilder(urlTplParams, this.requestAdapter);
    }
    ;
    /**
     * Instantiates a new SitesRequestBuilder and sets the default values.
     * @param pathParameters The raw url or the Url template parameters for the request.
     * @param requestAdapter The request adapter to use to execute the requests.
     */
    constructor(pathParameters, requestAdapter) {
        super(pathParameters, requestAdapter, "{+baseurl}/sites{?%24top,%24skip,%24search,%24filter,%24count,%24orderby,%24select,%24expand}");
    }
    ;
    /**
     * List all available [sites][] in an organization. Specific filter criteria and query options are also supported and described below: In addition, you can use a [$search][] query against the /sites collection to find sites matching given keywords.If you want to list all sites across all geographies, refer to getAllSites][]. For more guidance about building applications that use site discovery for scanning purposes, see [Best practices for discovering files and detecting changes at scale.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a Promise of SiteCollectionResponse
     * @see {@link https://learn.microsoft.com/graph/api/site-list?view=graph-rest-1.0|Find more info here}
     */
    get(requestConfiguration) {
        const requestInfo = this.toGetRequestInformation(requestConfiguration);
        const errorMapping = {
            "4XX": oDataError_1.createODataErrorFromDiscriminatorValue,
            "5XX": oDataError_1.createODataErrorFromDiscriminatorValue,
        };
        return this.requestAdapter.sendAsync(requestInfo, siteCollectionResponse_1.createSiteCollectionResponseFromDiscriminatorValue, errorMapping);
    }
    ;
    /**
     * List all available [sites][] in an organization. Specific filter criteria and query options are also supported and described below: In addition, you can use a [$search][] query against the /sites collection to find sites matching given keywords.If you want to list all sites across all geographies, refer to getAllSites][]. For more guidance about building applications that use site discovery for scanning purposes, see [Best practices for discovering files and detecting changes at scale.
     * @param requestConfiguration Configuration for the request such as headers, query parameters, and middleware options.
     * @returns a RequestInformation
     */
    toGetRequestInformation(requestConfiguration) {
        const requestInfo = new kiota_abstractions_1.RequestInformation(kiota_abstractions_1.HttpMethod.GET, this.urlTemplate, this.pathParameters);
        requestInfo.configure(requestConfiguration, sitesRequestBuilderGetQueryParametersMapper);
        requestInfo.headers.tryAdd("Accept", "application/json");
        return requestInfo;
    }
    ;
    /**
     * Returns a request builder with the provided arbitrary URL. Using this method means any other path or query parameters are ignored.
     * @param rawUrl The raw URL to use for the request builder.
     * @returns a sitesRequestBuilder
     */
    withUrl(rawUrl) {
        if (!rawUrl)
            throw new Error("rawUrl cannot be undefined");
        return new SitesRequestBuilder(rawUrl, this.requestAdapter);
    }
    ;
}
exports.SitesRequestBuilder = SitesRequestBuilder;
const sitesRequestBuilderGetQueryParametersMapper = {
    "count": "%24count",
    "expand": "%24expand",
    "filter": "%24filter",
    "orderby": "%24orderby",
    "search": "%24search",
    "select": "%24select",
    "skip": "%24skip",
    "top": "%24top",
};
// tslint:enable
// eslint-enable
